@@ -1,5 +1,5 @@
 package DateTime::TimeZone::Local::Win32;
-$DateTime::TimeZone::Local::Win32::VERSION = '1.85';
+$DateTime::TimeZone::Local::Win32::VERSION = '1.86';
 use 5.006;
 
 use strict;
@@ -135,6 +135,7 @@ sub EnvVars { return 'TZ' }
         'Newfoundland Standard Time'      => 'America/St_Johns',
         'North Asia East Standard Time'   => 'Asia/Irkutsk',
         'North Asia Standard Time'        => 'Asia/Krasnoyarsk',
+        'North Korea Standard Time'       => 'Asia/Pyongyang',
         'Pacific'                         => 'America/Los_Angeles',
         'Pacific SA'                      => 'America/Santiago',
         'Pacific SA Standard Time'        => 'America/Santiago',
@@ -204,6 +205,14 @@ sub EnvVars { return 'TZ' }
         'Yakutsk'                         => 'Asia/Yakutsk',
         'Yakutsk Standard Time'           => 'Asia/Yakutsk',
     );
+    
+    sub _WindowsToIANA {
+        my $class = shift;
+        
+        my $win_name = shift;
+
+        return $WinToIANA{$win_name};
+    }
 
     sub FromRegistry {
         my $class = shift;
@@ -217,7 +226,7 @@ sub EnvVars { return 'TZ' }
 
         return unless defined $win_name;
 
-        my $iana = $WinToIANA{$win_name};
+        my $iana = $class->_WindowsToIANA($win_name);
 
         return unless $iana;
 
@@ -282,7 +291,7 @@ DateTime::TimeZone::Local::Win32 - Determine the local system's time zone on Win
 
 =head1 VERSION
 
-version 1.85
+version 1.86
 
 =head1 SYNOPSIS
 
